@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -216,14 +216,13 @@ class ExecutionsAsyncClient:
         executions are ordered by their start time (newest
         first).
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
-            def sample_list_executions():
+            async def sample_list_executions():
                 # Create a client
-                client = executions_v1.ExecutionsClient()
+                client = executions_v1.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1.ListExecutionsRequest(
@@ -234,7 +233,7 @@ class ExecutionsAsyncClient:
                 page_result = client.list_executions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -299,12 +298,20 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListExecutionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -323,14 +330,13 @@ class ExecutionsAsyncClient:
         r"""Creates a new execution using the latest revision of
         the given workflow.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
-            def sample_create_execution():
+            async def sample_create_execution():
                 # Create a client
-                client = executions_v1.ExecutionsClient()
+                client = executions_v1.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1.CreateExecutionRequest(
@@ -338,7 +344,7 @@ class ExecutionsAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_execution(request=request)
+                response = await client.create_execution(request=request)
 
                 # Handle the response
                 print(response)
@@ -410,7 +416,12 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -426,13 +437,13 @@ class ExecutionsAsyncClient:
     ) -> executions.Execution:
         r"""Returns an execution of the given name.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
-            def sample_get_execution():
+            async def sample_get_execution():
                 # Create a client
-                client = executions_v1.ExecutionsClient()
+                client = executions_v1.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1.GetExecutionRequest(
@@ -440,7 +451,7 @@ class ExecutionsAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_execution(request=request)
+                response = await client.get_execution(request=request)
 
                 # Handle the response
                 print(response)
@@ -502,7 +513,12 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -518,13 +534,13 @@ class ExecutionsAsyncClient:
     ) -> executions.Execution:
         r"""Cancels an execution of the given name.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud.workflows import executions_v1
 
-            def sample_cancel_execution():
+            async def sample_cancel_execution():
                 # Create a client
-                client = executions_v1.ExecutionsClient()
+                client = executions_v1.ExecutionsAsyncClient()
 
                 # Initialize request argument(s)
                 request = executions_v1.CancelExecutionRequest(
@@ -532,7 +548,7 @@ class ExecutionsAsyncClient:
                 )
 
                 # Make the request
-                response = client.cancel_execution(request=request)
+                response = await client.cancel_execution(request=request)
 
                 # Handle the response
                 print(response)
@@ -594,7 +610,12 @@ class ExecutionsAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -608,7 +629,9 @@ class ExecutionsAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflow",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflow",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
