@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,7 +29,9 @@ from google.cloud.workflows.executions_v1beta.types import executions
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflow",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflow",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -78,6 +80,7 @@ class ExecutionsTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -119,25 +122,33 @@ class ExecutionsTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_executions: gapic_v1.method.wrap_method(
-                self.list_executions, default_timeout=None, client_info=client_info,
+                self.list_executions,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_execution: gapic_v1.method.wrap_method(
-                self.create_execution, default_timeout=None, client_info=client_info,
+                self.create_execution,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_execution: gapic_v1.method.wrap_method(
-                self.get_execution, default_timeout=None, client_info=client_info,
+                self.get_execution,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.cancel_execution: gapic_v1.method.wrap_method(
-                self.cancel_execution, default_timeout=None, client_info=client_info,
+                self.cancel_execution,
+                default_timeout=None,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -180,5 +191,9 @@ class ExecutionsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ExecutionsTransport",)
