@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -31,7 +31,9 @@ from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-workflows",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-workflows",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -80,6 +82,7 @@ class WorkflowsTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -121,28 +124,38 @@ class WorkflowsTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_workflows: gapic_v1.method.wrap_method(
-                self.list_workflows, default_timeout=None, client_info=client_info,
+                self.list_workflows,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_workflow: gapic_v1.method.wrap_method(
-                self.get_workflow, default_timeout=None, client_info=client_info,
+                self.get_workflow,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_workflow: gapic_v1.method.wrap_method(
-                self.create_workflow, default_timeout=None, client_info=client_info,
+                self.create_workflow,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_workflow: gapic_v1.method.wrap_method(
-                self.delete_workflow, default_timeout=None, client_info=client_info,
+                self.delete_workflow,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_workflow: gapic_v1.method.wrap_method(
-                self.update_workflow, default_timeout=None, client_info=client_info,
+                self.update_workflow,
+                default_timeout=None,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -198,5 +211,9 @@ class WorkflowsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("WorkflowsTransport",)
