@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -73,7 +73,7 @@ class Workflow(proto.Message):
         revision_create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The timestamp that the latest
             revision of the workflow was created.
-        labels (Sequence[google.cloud.workflows_v1.types.Workflow.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels associated with this workflow.
             Labels can contain at most 64 entries. Keys and
             values can be no longer than 63 characters and
@@ -110,18 +110,52 @@ class Workflow(proto.Message):
         STATE_UNSPECIFIED = 0
         ACTIVE = 1
 
-    name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=2,)
-    state = proto.Field(proto.ENUM, number=3, enum=State,)
-    revision_id = proto.Field(proto.STRING, number=4,)
-    create_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=State,
+    )
+    revision_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
     revision_create_time = proto.Field(
-        proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=7,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=8,
+    )
+    service_account = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    source_contents = proto.Field(
+        proto.STRING,
+        number=10,
+        oneof="source_code",
     )
-    labels = proto.MapField(proto.STRING, proto.STRING, number=8,)
-    service_account = proto.Field(proto.STRING, number=9,)
-    source_contents = proto.Field(proto.STRING, number=10, oneof="source_code",)
 
 
 class ListWorkflowsRequest(proto.Message):
@@ -161,11 +195,26 @@ class ListWorkflowsRequest(proto.Message):
             in an unspecified order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListWorkflowsResponse(proto.Message):
@@ -188,9 +237,19 @@ class ListWorkflowsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    workflows = proto.RepeatedField(proto.MESSAGE, number=1, message="Workflow",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    workflows = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Workflow",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetWorkflowRequest(proto.Message):
@@ -205,7 +264,10 @@ class GetWorkflowRequest(proto.Message):
             projects/{project}/locations/{location}/workflows/{workflow}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateWorkflowRequest(proto.Message):
@@ -232,9 +294,19 @@ class CreateWorkflowRequest(proto.Message):
             -  Must be unique within the customer project and location.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    workflow = proto.Field(proto.MESSAGE, number=2, message="Workflow",)
-    workflow_id = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    workflow = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Workflow",
+    )
+    workflow_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class DeleteWorkflowRequest(proto.Message):
@@ -249,7 +321,10 @@ class DeleteWorkflowRequest(proto.Message):
             projects/{project}/locations/{location}/workflows/{workflow}
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateWorkflowRequest(proto.Message):
@@ -265,9 +340,15 @@ class UpdateWorkflowRequest(proto.Message):
             the entire workflow will be updated.
     """
 
-    workflow = proto.Field(proto.MESSAGE, number=1, message="Workflow",)
+    workflow = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Workflow",
+    )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -288,11 +369,28 @@ class OperationMetadata(proto.Message):
             API version used to start the operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    api_version = proto.Field(proto.STRING, number=5,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
